"""
### Moveread Pipelines: DFY
> Full DFY pipeline for Moveread
"""
import lazy_loader as lazy
__getattr__, __dir__, __all__ = lazy.attach_stub(__name__, __file__)